==> ulyxex.1.4.7.alone.zip: pages/admin_site.php <==
<?php
/* Ulyxex version 1.4.7 *****************/
if (!isset($admin)) exit;
if ($_SESSION['userid'] != 1) exit("you can't modify this page !");
require_once("core/admin_site.php");
/****************************************/
/* page elements						*/
$o_adminSite = New AdminSite();
$meta = $h->meta("Content-Type","text/html; charset=UTF-8");
$css = $h->css("css/".ADMINCSS,"external");
$js = $h->script("js/ulyxex.js","external");
$title = $h->title($t->wr("site by")."admin");
$head = $h->head($meta.$css.$js.$title);

$topPage = $h->h1($t->wr("site by").$h->span("admin","class='username'"));
$topPage .= $h->h2($adminNavigation->links);

$tinyMceVers = "...";
$Lines = @file("js/tiny-version.txt");
if ($Lines) {
	foreach($Lines as $Line) {
		// change line if needed
		if (substr($Line, 0, 7) == 'TinyMCE') {
			$tinyMceVers = substr($Line, 8);
		}
	}
}

$bottomPage  = $h->h3("Site Infos:");
$_ = array(
	"field width"		=> FIELDWIDTH,
	"root directory"	=> getcwd(),
	"mysql-version"		=> $o_adminSite->mysql_version(),
	"host"				=> HOSTMYSQL,
	"base"				=> BASEMYSQL,
	"prefix"			=> $prefixTableMySql,
	"user"				=> USERMYSQL,
	"php-version"		=> phpversion(),
	"tinyMce-version"   => $tinyMceVers
);

foreach($_ as $k=>$v) {
	$bottomPage .= $h->p("- ".ucfirst($k)." : ".$h->b($v));
}
$bottomPage .= $h->p("- ".$h->ahref("admin.php?action=phpinfo","More phpinfo"));
$bottomPage .= $h->ulyxCredits($firstLine=False);
/****************************************/
/* page data							*/	
$data = "";
if (!empty($_POST['update'])) $data .= $o_adminSite->update_site_params();
$data .= $o_adminSite->site_params();

/****************************************/
/* show									*/
$bottomPage .= $h->countQ();
$body = $h->body($topPage.$data.$bottomPage);
$page = $h->html($head.$body);

echo $page;
?>

==> ulyxex.1.5.0.3.alone.zip: pages/admin_site.php <==
<?php
/* Ulyxex version 1.5.0.3 *****************/
if (!isset($admin)) exit;
if ($_SESSION['userid'] != 1) exit("you can't modify this page !");
require_once("core/admin_site.php");
/****************************************/
/* page elements						*/
$o_adminSite = New AdminSite();
$meta = $h->meta("Content-Type","text/html; charset=UTF-8");
$css = $h->css("css/".ADMINCSS,"external");
$js = $h->script("js/ulyxex.js","external");
$title = $h->title($t->wr("site by")."admin");
$head = $h->head($meta.$css.$js.$title);

$topPage = $h->h1($t->wr("site by").$h->span("admin","class='username'"));
$topPage .= $h->h2($adminNavigation->links);

$tinyMceVers = "...";
$Lines = @file("js/tiny-version.txt");
if ($Lines) {
	foreach($Lines as $Line) {
		if (substr($Line, 0, 7) == 'TinyMCE') {
			$tinyMceVers = substr($Line, 8);
		}
	}
}

$bottomPage  = $h->h3("Site Infos:");
$_ = array(
	"field width"		=> FIELDWIDTH,
	"root directory"	=> getcwd(),
	"mysql-version"		=> $o_adminSite->mysql_version(),
	"host"				=> HOSTMYSQL,
	"base"				=> BASEMYSQL,
	"prefix"			=> $prefixTableMySql,
	"user"				=> USERMYSQL,
	"php-version"		=> phpversion(),
	"tinyMce-version"   => $tinyMceVers,
);

foreach($_ as $k=>$v) {
	$bottomPage .= $h->p("- ".ucfirst($k)." : ".$h->b($v));
}
$bottomPage .= $h->p("- ".$h->ahref("admin.php?action=phpinfo","More phpinfo"));
$bottomPage .= $h->ulyxCredits($firstLine=False);
/****************************************/
/* page data							*/	
$data = "";
if (!empty($_POST['update'])) $data .= $o_adminSite->update_site_params();
$data .= $o_adminSite->site_params();

/****************************************/
/* show									*/
$bottomPage .= $h->countQ();
$body = $h->body($topPage.$data.$bottomPage);
$page = $h->html($head.$body);

echo $page;
?>
